@@ -4,14 +4,8 @@
 Package | `__init__.py`
 
 Daniel Bakas Amuchastegui\
-March 16, 2020
+March 18, 2020
 
 Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 '''
-
-from . import graph, identifier, namespace, node
-from .graph import *
-from .identifier import *
-from .namespace import *
-from .node import *
\ No newline at end of file
