@@ -10,13 +10,13 @@ Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 '''
 
-import uuid
+from uuid import uuid4
+
 
 def generate_uuid():
-    letters = {'a','b','c','d','e','f'}
     result = '0'
-    while result[0] not in letters:
-        result = uuid.uuid4().hex
-        result = result[0:8] + '_' + result[8:12] + '_' + result[12:16] 
-        + '_' + result[16:20] + '_' + result[20:]
-    return result
\ No newline at end of file
+    while result[0] not in ('a', 'b', 'c', 'd', 'e', 'f'):
+        result = uuid4().hex
+        result = result[0:8] + '_' + result[8:12] + '_' + \
+            result[12:16] + '_' + result[16:20] + '_' + result[20:]
+    return result
